==> openshift-model-config-6.1.1-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterOperatorStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimFluent;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.HasMetadata;
import java.lang.Object;
import java.util.Map;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimBuilder;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaim;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.Iterator;
import java.lang.Integer;

 /**
  * Generated
  */
public interface ClusterOperatorStatusFluent<A extends ClusterOperatorStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,ClusterOperatorStatusCondition item);
  public A setToConditions(Integer index,ClusterOperatorStatusCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.config.v1.ClusterOperatorStatusCondition... items);
  public A addAllToConditions(Collection<ClusterOperatorStatusCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.config.v1.ClusterOperatorStatusCondition... items);
  public A removeAllFromConditions(Collection<ClusterOperatorStatusCondition> items);
  public A removeMatchingFromConditions(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterOperatorStatusCondition> getConditions();
  public List<ClusterOperatorStatusCondition> buildConditions();
  public ClusterOperatorStatusCondition buildCondition(Integer index);
  public ClusterOperatorStatusCondition buildFirstCondition();
  public ClusterOperatorStatusCondition buildLastCondition();
  public ClusterOperatorStatusCondition buildMatchingCondition(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  public A withConditions(List<ClusterOperatorStatusCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.config.v1.ClusterOperatorStatusCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public ClusterOperatorStatusFluent.ConditionsNested<A> addNewCondition();
  public ClusterOperatorStatusFluent.ConditionsNested<A> addNewConditionLike(ClusterOperatorStatusCondition item);
  public ClusterOperatorStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,ClusterOperatorStatusCondition item);
  public ClusterOperatorStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ClusterOperatorStatusFluent.ConditionsNested<A> editFirstCondition();
  public ClusterOperatorStatusFluent.ConditionsNested<A> editLastCondition();
  public ClusterOperatorStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExtension instead.
   * @return The buildable object.
   */
  @Deprecated
  public HasMetadata getExtension();
  public HasMetadata buildExtension();
  public A withExtension(HasMetadata extension);
  public Boolean hasExtension();
  public A withBuildExtension(Build buildExtension);
  public ClusterOperatorStatusFluent.BuildExtensionNested<A> withNewBuildExtension();
  public ClusterOperatorStatusFluent.BuildExtensionNested<A> withNewBuildExtensionLike(Build item);
  public A withProjectExtension(Project projectExtension);
  public ClusterOperatorStatusFluent.ProjectExtensionNested<A> withNewProjectExtension();
  public ClusterOperatorStatusFluent.ProjectExtensionNested<A> withNewProjectExtensionLike(Project item);
  public A withClusterVersionExtension(ClusterVersion clusterVersionExtension);
  public ClusterOperatorStatusFluent.ClusterVersionExtensionNested<A> withNewClusterVersionExtension();
  public ClusterOperatorStatusFluent.ClusterVersionExtensionNested<A> withNewClusterVersionExtensionLike(ClusterVersion item);
  public A withImageContentPolicyExtension(ImageContentPolicy imageContentPolicyExtension);
  public ClusterOperatorStatusFluent.ImageContentPolicyExtensionNested<A> withNewImageContentPolicyExtension();
  public ClusterOperatorStatusFluent.ImageContentPolicyExtensionNested<A> withNewImageContentPolicyExtensionLike(ImageContentPolicy item);
  public A withAPIServerExtension(APIServer aPIServerExtension);
  public ClusterOperatorStatusFluent.APIServerExtensionNested<A> withNewAPIServerExtension();
  public ClusterOperatorStatusFluent.APIServerExtensionNested<A> withNewAPIServerExtensionLike(APIServer item);
  public A withPersistentVolumeClaimExtension(PersistentVolumeClaim persistentVolumeClaimExtension);
  public ClusterOperatorStatusFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtension();
  public ClusterOperatorStatusFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtensionLike(PersistentVolumeClaim item);
  public A withIngressExtension(Ingress ingressExtension);
  public ClusterOperatorStatusFluent.IngressExtensionNested<A> withNewIngressExtension();
  public ClusterOperatorStatusFluent.IngressExtensionNested<A> withNewIngressExtensionLike(Ingress item);
  public A withAuthenticationExtension(Authentication authenticationExtension);
  public ClusterOperatorStatusFluent.AuthenticationExtensionNested<A> withNewAuthenticationExtension();
  public ClusterOperatorStatusFluent.AuthenticationExtensionNested<A> withNewAuthenticationExtensionLike(Authentication item);
  public A withImageExtension(Image imageExtension);
  public ClusterOperatorStatusFluent.ImageExtensionNested<A> withNewImageExtension();
  public ClusterOperatorStatusFluent.ImageExtensionNested<A> withNewImageExtensionLike(Image item);
  public A withDNSExtension(DNS dNSExtension);
  public ClusterOperatorStatusFluent.DNSExtensionNested<A> withNewDNSExtension();
  public ClusterOperatorStatusFluent.DNSExtensionNested<A> withNewDNSExtensionLike(DNS item);
  public A withNetworkExtension(Network networkExtension);
  public ClusterOperatorStatusFluent.NetworkExtensionNested<A> withNewNetworkExtension();
  public ClusterOperatorStatusFluent.NetworkExtensionNested<A> withNewNetworkExtensionLike(Network item);
  public A withConsoleExtension(Console consoleExtension);
  public ClusterOperatorStatusFluent.ConsoleExtensionNested<A> withNewConsoleExtension();
  public ClusterOperatorStatusFluent.ConsoleExtensionNested<A> withNewConsoleExtensionLike(Console item);
  public A withSchedulerExtension(Scheduler schedulerExtension);
  public ClusterOperatorStatusFluent.SchedulerExtensionNested<A> withNewSchedulerExtension();
  public ClusterOperatorStatusFluent.SchedulerExtensionNested<A> withNewSchedulerExtensionLike(Scheduler item);
  public A withFeatureGateExtension(FeatureGate featureGateExtension);
  public ClusterOperatorStatusFluent.FeatureGateExtensionNested<A> withNewFeatureGateExtension();
  public ClusterOperatorStatusFluent.FeatureGateExtensionNested<A> withNewFeatureGateExtensionLike(FeatureGate item);
  public A withOperatorHubExtension(OperatorHub operatorHubExtension);
  public ClusterOperatorStatusFluent.OperatorHubExtensionNested<A> withNewOperatorHubExtension();
  public ClusterOperatorStatusFluent.OperatorHubExtensionNested<A> withNewOperatorHubExtensionLike(OperatorHub item);
  public A withOAuthExtension(OAuth oAuthExtension);
  public ClusterOperatorStatusFluent.OAuthExtensionNested<A> withNewOAuthExtension();
  public ClusterOperatorStatusFluent.OAuthExtensionNested<A> withNewOAuthExtensionLike(OAuth item);
  public A withClusterOperatorExtension(ClusterOperator clusterOperatorExtension);
  public ClusterOperatorStatusFluent.ClusterOperatorExtensionNested<A> withNewClusterOperatorExtension();
  public ClusterOperatorStatusFluent.ClusterOperatorExtensionNested<A> withNewClusterOperatorExtensionLike(ClusterOperator item);
  public A withInfrastructureExtension(Infrastructure infrastructureExtension);
  public ClusterOperatorStatusFluent.InfrastructureExtensionNested<A> withNewInfrastructureExtension();
  public ClusterOperatorStatusFluent.InfrastructureExtensionNested<A> withNewInfrastructureExtensionLike(Infrastructure item);
  public A withProxyExtension(Proxy proxyExtension);
  public ClusterOperatorStatusFluent.ProxyExtensionNested<A> withNewProxyExtension();
  public ClusterOperatorStatusFluent.ProxyExtensionNested<A> withNewProxyExtensionLike(Proxy item);
  public A addToRelatedObjects(Integer index,ObjectReference item);
  public A setToRelatedObjects(Integer index,ObjectReference item);
  public A addToRelatedObjects(io.fabric8.openshift.api.model.config.v1.ObjectReference... items);
  public A addAllToRelatedObjects(Collection<ObjectReference> items);
  public A removeFromRelatedObjects(io.fabric8.openshift.api.model.config.v1.ObjectReference... items);
  public A removeAllFromRelatedObjects(Collection<ObjectReference> items);
  public A removeMatchingFromRelatedObjects(Predicate<ObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRelatedObjects instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ObjectReference> getRelatedObjects();
  public List<ObjectReference> buildRelatedObjects();
  public ObjectReference buildRelatedObject(Integer index);
  public ObjectReference buildFirstRelatedObject();
  public ObjectReference buildLastRelatedObject();
  public ObjectReference buildMatchingRelatedObject(Predicate<ObjectReferenceBuilder> predicate);
  public Boolean hasMatchingRelatedObject(Predicate<ObjectReferenceBuilder> predicate);
  public A withRelatedObjects(List<ObjectReference> relatedObjects);
  public A withRelatedObjects(io.fabric8.openshift.api.model.config.v1.ObjectReference... relatedObjects);
  public Boolean hasRelatedObjects();
  public A addNewRelatedObject(String group,String name,String namespace,String resource);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> addNewRelatedObject();
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> addNewRelatedObjectLike(ObjectReference item);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> setNewRelatedObjectLike(Integer index,ObjectReference item);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editRelatedObject(Integer index);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editFirstRelatedObject();
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editLastRelatedObject();
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editMatchingRelatedObject(Predicate<ObjectReferenceBuilder> predicate);
  public A addToVersions(Integer index,OperandVersion item);
  public A setToVersions(Integer index,OperandVersion item);
  public A addToVersions(io.fabric8.openshift.api.model.config.v1.OperandVersion... items);
  public A addAllToVersions(Collection<OperandVersion> items);
  public A removeFromVersions(io.fabric8.openshift.api.model.config.v1.OperandVersion... items);
  public A removeAllFromVersions(Collection<OperandVersion> items);
  public A removeMatchingFromVersions(Predicate<OperandVersionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildVersions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OperandVersion> getVersions();
  public List<OperandVersion> buildVersions();
  public OperandVersion buildVersion(Integer index);
  public OperandVersion buildFirstVersion();
  public OperandVersion buildLastVersion();
  public OperandVersion buildMatchingVersion(Predicate<OperandVersionBuilder> predicate);
  public Boolean hasMatchingVersion(Predicate<OperandVersionBuilder> predicate);
  public A withVersions(List<OperandVersion> versions);
  public A withVersions(io.fabric8.openshift.api.model.config.v1.OperandVersion... versions);
  public Boolean hasVersions();
  public A addNewVersion(String name,String version);
  public ClusterOperatorStatusFluent.VersionsNested<A> addNewVersion();
  public ClusterOperatorStatusFluent.VersionsNested<A> addNewVersionLike(OperandVersion item);
  public ClusterOperatorStatusFluent.VersionsNested<A> setNewVersionLike(Integer index,OperandVersion item);
  public ClusterOperatorStatusFluent.VersionsNested<A> editVersion(Integer index);
  public ClusterOperatorStatusFluent.VersionsNested<A> editFirstVersion();
  public ClusterOperatorStatusFluent.VersionsNested<A> editLastVersion();
  public ClusterOperatorStatusFluent.VersionsNested<A> editMatchingVersion(Predicate<OperandVersionBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,ClusterOperatorStatusConditionFluent<ClusterOperatorStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface BuildExtensionNested<N> extends Nested<N>,BuildFluent<ClusterOperatorStatusFluent.BuildExtensionNested<N>>{
    public N and();
    public N endBuildExtension();
    
  }
  public interface ProjectExtensionNested<N> extends Nested<N>,ProjectFluent<ClusterOperatorStatusFluent.ProjectExtensionNested<N>>{
    public N and();
    public N endProjectExtension();
    
  }
  public interface ClusterVersionExtensionNested<N> extends Nested<N>,ClusterVersionFluent<ClusterOperatorStatusFluent.ClusterVersionExtensionNested<N>>{
    public N and();
    public N endClusterVersionExtension();
    
  }
  public interface ImageContentPolicyExtensionNested<N> extends Nested<N>,ImageContentPolicyFluent<ClusterOperatorStatusFluent.ImageContentPolicyExtensionNested<N>>{
    public N and();
    public N endImageContentPolicyExtension();
    
  }
  public interface APIServerExtensionNested<N> extends Nested<N>,APIServerFluent<ClusterOperatorStatusFluent.APIServerExtensionNested<N>>{
    public N and();
    public N endAPIServerExtension();
    
  }
  public interface PersistentVolumeClaimExtensionNested<N> extends Nested<N>,PersistentVolumeClaimFluent<ClusterOperatorStatusFluent.PersistentVolumeClaimExtensionNested<N>>{
    public N and();
    public N endPersistentVolumeClaimExtension();
    
  }
  public interface IngressExtensionNested<N> extends Nested<N>,IngressFluent<ClusterOperatorStatusFluent.IngressExtensionNested<N>>{
    public N and();
    public N endIngressExtension();
    
  }
  public interface AuthenticationExtensionNested<N> extends Nested<N>,AuthenticationFluent<ClusterOperatorStatusFluent.AuthenticationExtensionNested<N>>{
    public N and();
    public N endAuthenticationExtension();
    
  }
  public interface ImageExtensionNested<N> extends Nested<N>,ImageFluent<ClusterOperatorStatusFluent.ImageExtensionNested<N>>{
    public N and();
    public N endImageExtension();
    
  }
  public interface DNSExtensionNested<N> extends Nested<N>,DNSFluent<ClusterOperatorStatusFluent.DNSExtensionNested<N>>{
    public N and();
    public N endDNSExtension();
    
  }
  public interface NetworkExtensionNested<N> extends Nested<N>,NetworkFluent<ClusterOperatorStatusFluent.NetworkExtensionNested<N>>{
    public N and();
    public N endNetworkExtension();
    
  }
  public interface ConsoleExtensionNested<N> extends Nested<N>,ConsoleFluent<ClusterOperatorStatusFluent.ConsoleExtensionNested<N>>{
    public N and();
    public N endConsoleExtension();
    
  }
  public interface SchedulerExtensionNested<N> extends Nested<N>,SchedulerFluent<ClusterOperatorStatusFluent.SchedulerExtensionNested<N>>{
    public N and();
    public N endSchedulerExtension();
    
  }
  public interface FeatureGateExtensionNested<N> extends Nested<N>,FeatureGateFluent<ClusterOperatorStatusFluent.FeatureGateExtensionNested<N>>{
    public N and();
    public N endFeatureGateExtension();
    
  }
  public interface OperatorHubExtensionNested<N> extends Nested<N>,OperatorHubFluent<ClusterOperatorStatusFluent.OperatorHubExtensionNested<N>>{
    public N and();
    public N endOperatorHubExtension();
    
  }
  public interface OAuthExtensionNested<N> extends Nested<N>,OAuthFluent<ClusterOperatorStatusFluent.OAuthExtensionNested<N>>{
    public N and();
    public N endOAuthExtension();
    
  }
  public interface ClusterOperatorExtensionNested<N> extends Nested<N>,ClusterOperatorFluent<ClusterOperatorStatusFluent.ClusterOperatorExtensionNested<N>>{
    public N and();
    public N endClusterOperatorExtension();
    
  }
  public interface InfrastructureExtensionNested<N> extends Nested<N>,InfrastructureFluent<ClusterOperatorStatusFluent.InfrastructureExtensionNested<N>>{
    public N and();
    public N endInfrastructureExtension();
    
  }
  public interface ProxyExtensionNested<N> extends Nested<N>,ProxyFluent<ClusterOperatorStatusFluent.ProxyExtensionNested<N>>{
    public N and();
    public N endProxyExtension();
    
  }
  public interface RelatedObjectsNested<N> extends Nested<N>,ObjectReferenceFluent<ClusterOperatorStatusFluent.RelatedObjectsNested<N>>{
    public N and();
    public N endRelatedObject();
    
  }
  public interface VersionsNested<N> extends Nested<N>,OperandVersionFluent<ClusterOperatorStatusFluent.VersionsNested<N>>{
    public N and();
    public N endVersion();
    
  }
  
}

==> openshift-model-config-6.6.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterOperatorStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.runtime.RawExtension;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterOperatorStatusFluent<A extends ClusterOperatorStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,ClusterOperatorStatusCondition item);
  public A setToConditions(Integer index,ClusterOperatorStatusCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.config.v1.ClusterOperatorStatusCondition... items);
  public A addAllToConditions(Collection<ClusterOperatorStatusCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.config.v1.ClusterOperatorStatusCondition... items);
  public A removeAllFromConditions(Collection<ClusterOperatorStatusCondition> items);
  public A removeMatchingFromConditions(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterOperatorStatusCondition> getConditions();
  public List<ClusterOperatorStatusCondition> buildConditions();
  public ClusterOperatorStatusCondition buildCondition(Integer index);
  public ClusterOperatorStatusCondition buildFirstCondition();
  public ClusterOperatorStatusCondition buildLastCondition();
  public ClusterOperatorStatusCondition buildMatchingCondition(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  public A withConditions(List<ClusterOperatorStatusCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.config.v1.ClusterOperatorStatusCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public ClusterOperatorStatusFluent.ConditionsNested<A> addNewCondition();
  public ClusterOperatorStatusFluent.ConditionsNested<A> addNewConditionLike(ClusterOperatorStatusCondition item);
  public ClusterOperatorStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,ClusterOperatorStatusCondition item);
  public ClusterOperatorStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ClusterOperatorStatusFluent.ConditionsNested<A> editFirstCondition();
  public ClusterOperatorStatusFluent.ConditionsNested<A> editLastCondition();
  public ClusterOperatorStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ClusterOperatorStatusConditionBuilder> predicate);
  public RawExtension getExtension();
  public A withExtension(RawExtension extension);
  public Boolean hasExtension();
  public A withNewExtension(Object value);
  public A addToRelatedObjects(Integer index,ObjectReference item);
  public A setToRelatedObjects(Integer index,ObjectReference item);
  public A addToRelatedObjects(io.fabric8.openshift.api.model.config.v1.ObjectReference... items);
  public A addAllToRelatedObjects(Collection<ObjectReference> items);
  public A removeFromRelatedObjects(io.fabric8.openshift.api.model.config.v1.ObjectReference... items);
  public A removeAllFromRelatedObjects(Collection<ObjectReference> items);
  public A removeMatchingFromRelatedObjects(Predicate<ObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRelatedObjects instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ObjectReference> getRelatedObjects();
  public List<ObjectReference> buildRelatedObjects();
  public ObjectReference buildRelatedObject(Integer index);
  public ObjectReference buildFirstRelatedObject();
  public ObjectReference buildLastRelatedObject();
  public ObjectReference buildMatchingRelatedObject(Predicate<ObjectReferenceBuilder> predicate);
  public Boolean hasMatchingRelatedObject(Predicate<ObjectReferenceBuilder> predicate);
  public A withRelatedObjects(List<ObjectReference> relatedObjects);
  public A withRelatedObjects(io.fabric8.openshift.api.model.config.v1.ObjectReference... relatedObjects);
  public Boolean hasRelatedObjects();
  public A addNewRelatedObject(String group,String name,String namespace,String resource);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> addNewRelatedObject();
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> addNewRelatedObjectLike(ObjectReference item);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> setNewRelatedObjectLike(Integer index,ObjectReference item);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editRelatedObject(Integer index);
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editFirstRelatedObject();
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editLastRelatedObject();
  public ClusterOperatorStatusFluent.RelatedObjectsNested<A> editMatchingRelatedObject(Predicate<ObjectReferenceBuilder> predicate);
  public A addToVersions(Integer index,OperandVersion item);
  public A setToVersions(Integer index,OperandVersion item);
  public A addToVersions(io.fabric8.openshift.api.model.config.v1.OperandVersion... items);
  public A addAllToVersions(Collection<OperandVersion> items);
  public A removeFromVersions(io.fabric8.openshift.api.model.config.v1.OperandVersion... items);
  public A removeAllFromVersions(Collection<OperandVersion> items);
  public A removeMatchingFromVersions(Predicate<OperandVersionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildVersions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OperandVersion> getVersions();
  public List<OperandVersion> buildVersions();
  public OperandVersion buildVersion(Integer index);
  public OperandVersion buildFirstVersion();
  public OperandVersion buildLastVersion();
  public OperandVersion buildMatchingVersion(Predicate<OperandVersionBuilder> predicate);
  public Boolean hasMatchingVersion(Predicate<OperandVersionBuilder> predicate);
  public A withVersions(List<OperandVersion> versions);
  public A withVersions(io.fabric8.openshift.api.model.config.v1.OperandVersion... versions);
  public Boolean hasVersions();
  public A addNewVersion(String name,String version);
  public ClusterOperatorStatusFluent.VersionsNested<A> addNewVersion();
  public ClusterOperatorStatusFluent.VersionsNested<A> addNewVersionLike(OperandVersion item);
  public ClusterOperatorStatusFluent.VersionsNested<A> setNewVersionLike(Integer index,OperandVersion item);
  public ClusterOperatorStatusFluent.VersionsNested<A> editVersion(Integer index);
  public ClusterOperatorStatusFluent.VersionsNested<A> editFirstVersion();
  public ClusterOperatorStatusFluent.VersionsNested<A> editLastVersion();
  public ClusterOperatorStatusFluent.VersionsNested<A> editMatchingVersion(Predicate<OperandVersionBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,ClusterOperatorStatusConditionFluent<ClusterOperatorStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface RelatedObjectsNested<N> extends Nested<N>,ObjectReferenceFluent<ClusterOperatorStatusFluent.RelatedObjectsNested<N>>{
    public N and();
    public N endRelatedObject();
    
  }
  public interface VersionsNested<N> extends Nested<N>,OperandVersionFluent<ClusterOperatorStatusFluent.VersionsNested<N>>{
    public N and();
    public N endVersion();
    
  }
  
}
